<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Deepin IDでログインしてください。</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>この操作を行うにはログインする必要があります。</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>リクエストが多すぎます。しばらく経ってからお試しください。</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>この操作を行うにはログインする必要があります。</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>ネットワークエラーです。もう一度お試しください。</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>ログアウト済み</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>マイ フィードバック</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>サインアウト</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>サインイン</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1回表示</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>提案</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>お気に入り解除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>お気に入り登録</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>強い要求を解除</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>強い要求</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>まもなく公開</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>公式の回答</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>タイプ:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>バグ</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>提案</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>並べ替え:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>最新</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>強い要求</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>コミュニケーション</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>ここで議論をして共有しましょう</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>バグの報告</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>発見した問題を報告してください</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>提案</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>改善を提案してみませんか</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>リソース</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>アンケート</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>参加する</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>内部テスト</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>グローバル翻訳</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>公式ニュース</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>表示するものはありません</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>アンケート</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>システム起動時に開く</translation>
    </message>
    <message>
        <source>About</source>
        <translation>このアプリについて</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>フォーラムへのクイックログイン、改善の提案、バグの報告が行えます。</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>まだメッセージはありません。</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1件のメッセージ</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>すべて既読にする</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>もっと見る</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>ネットワークエラーです。もう一度お試しください。</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>まだアンケートはありません。</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>期限: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>埋める</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>保留中</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>再現中</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>確認済み</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>返信済み</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>解決済み</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>評価中</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>承認済み</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>完了</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>問題の処理が完了していないため、公開リストに表示されていません。</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>現時点では問題を特定できていません。継続的な調査と監視が必要です。</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>問題は再現され、原因が特定されました。</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>この問題はバグや不自然なものではありません。</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>この問題は解決され、正式リリースを待機中です。</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>要件が処理されていないため、公開リストに表示されていません。</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>問題は確認され、現在評価中です。</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>将来のリリース計画に含まれています。</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>要件を受け入れられないか、対応できません。</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>開発が完了し、正式リリースを待機中です。</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>スクリーンショットを追加できません。</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>画像ファイルの大きさは1MB以下である必要があります。</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>画像ファイルのフォーマットがサポートされていません。</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Current Status of the Product]: 
[Desired Product]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>フィードバックを提出</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>タイプ：</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>提案</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>バグの報告</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation> タイトル：</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>問題の簡単な説明を入力してください</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>本文：</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>１つのフィードバックに複数の問題を含めないでください。</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>１つのフィードバックに複数の問題を含めないでください。</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>メールアドレス：</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>メールアドレスを入力してください</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>システムバージョン：</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>デバイス情報：</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;home://sysinfo&apos;&gt;デバイス情報&lt;/a&gt;のアップロード</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>スクリーンショット：</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>画像ファイル</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>ドラッグ&amp;ドロップかボタンをクリックして画像を追加してください</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>フィードバックの提出を終了してもよろしいですか？</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>フィードバックの内容は保存されません。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>提出</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>フィードバックを提出できません。</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>タイトルと本文が入力されていることを確認してください。</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>タイトルが入力されていることを確認してください。</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>本文が入力されていることを確認してください。</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>間違ったメールアドレスが入力されています。</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>デバイス情報</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Feedback Hub</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>送信したフィードバック</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>強い要求に指定</translation>
    </message>
</context>
</TS>